@@ -111,7 +111,7 @@ class ImapSmtp:
     .. code-block:: robotframework
 
         *** Settings ***
-        Library     RPA.Email.ImapSmtp   smtp_server=smtp.gmail.com  port=587
+        Library     RPA.Email.ImapSmtp   smtp_server=smtp.gmail.com  smtp_port=587
         Task Setup  Authorize  account=${GMAIL_ACCOUNT}  password=${GMAIL_PASSWORD}
 
         *** Variables ***
@@ -151,7 +151,7 @@ class ImapSmtp:
         gmail_password = "ACCOUNT_PASSWORD"
         sender = gmail_account
 
-        mail = ImapSmtp(smtp_server="smtp.gmail.com", port=587)
+        mail = ImapSmtp(smtp_server="smtp.gmail.com", smtp_port=587)
         mail.authorize(account=gmail_account, password=gmail_password)
         mail.send_message(
             sender=gmail_account,
@@ -198,7 +198,10 @@ class ImapSmtp:
                 self.smtp_conn = None
 
         if self.imap_conn:
-            self.imap_conn.logout()
+            try:
+                self.imap_conn.logout()
+            except Exception:  # pylint: disable=W0703
+                pass
             self.imap_conn = None
 
     def set_credentials(self, account: str = None, password: str = None) -> None:
@@ -547,9 +550,10 @@ class ImapSmtp:
                     (html.strip(), has_attachments) if html else ("", has_attachments)
                 )
         else:
+            content_charset = message.get_content_charset()
             text = str(
                 message.get_payload(decode=True),
-                message.get_content_charset(),
+                content_charset or "utf8",
                 "ignore",
             ).encode("utf8", "replace")
             return text.strip(), has_attachments
@@ -744,8 +748,18 @@ class ImapSmtp:
         result = self._do_actions_on_messages(
             criterion, source_folder=source_folder, actions=[Action.msg_list]
         )
-        self.logger.info(result)
-        return result["uids"].values()
+        values = result["uids"].values()
+        converted = []
+        for v in values:
+            converted.append(
+                {
+                    str(key): value
+                    if isinstance(value, (str, bool, int))
+                    else str(value)
+                    for key, value in v.items()
+                }
+            )
+        return converted
 
     @imap_connection
     def save_attachments(
@@ -805,7 +819,7 @@ class ImapSmtp:
             content_maintype = part.get_content_maintype()
             content_disposition = part.get("Content-Disposition")
             if content_maintype != "multipart" and content_disposition is not None:
-                filename = part.get_filename()
+                filename = Path(part.get_filename()).name
                 if bool(filename):
                     filepath = Path(target_folder) / filename
                     if not filepath.exists() or overwrite:
@@ -858,13 +872,13 @@ class ImapSmtp:
 
     def _parse_folders(self, folders):
         parsed_folders = []
-        folder_regex = r'\((?P<flags>.*)\)."(?P<delimiter>.*)"."(?P<name>.*)".*'
+        folder_regex = r'\((?P<flags>.*)\)\s"(?P<delimiter>.*)"\s"?(?P<name>[^"]*)"?'
         for f in folders:
-            flags, delimiter, name = re.search(folder_regex, bytes.decode(f)).groups()
-
-            parsed_folders.append(
-                {"name": name, "flags": flags, "delimiter": delimiter}
-            )
+            match = re.search(folder_regex, bytes.decode(f))
+            if not match:
+                self.logger.warning("Cannot parse folder name %s", bytes.decode(f))
+                continue
+            parsed_folders.append(match.groupdict())
         return parsed_folders
 
     @imap_connection
